<?php

/**
 * Implementation of hook_panels_content_types
 */
function activity_panels_content_types() {
  $activity_content_type = array(
    'description' => array(
      'title' => t('Activity'),
      'icon' => 'icon_user.png',
      'path' => panels_get_path('content_types/user'),
      'description' => t('Activity report for user and buddies'),
      'required context' => new panels_required_context(t('User'), 'user'),
      'category' => array(t('User context'), -9),
    ),
  );
  
  $items['activity'] = array(
    'title' => t('Activity'),
    'content_types' => $activity_content_type,
    'single' => TRUE,
    'render callback' => 'activity_panels_content',
    'add callback' => 'activity_panels_configure',
    'edit callback' => 'activity_panels_configure',
    'title callback' => 'activity_panels_configure_title',
  );
  
  return $items;
}

/**
 * Output function for the 'activity' content type.
 */
function activity_panels_content($conf, $panel_args, $context) {
  $account = isset($context->data) ? drupal_clone($context->data) : NULL;
  $block->module = 'activity';
  $block->title = "Activity";

  if ($account) {
    switch ($conf['whose']) {
      case 'user':
        $block->title = "My Activity";
        $activities = activity_get_activity($account->uid);
        if (count($activities)) {
          $block->content =  theme('activity_block', $activities);
        }
        break;

      case 'buddies':
        $block->title = "My Buddies Activity";
        $uids = array_keys(buddylist_get_buddies($account->uid, 'uid'));
        $activities = activity_get_activity($uids, NULL, 5);
        if (count($activities)) {
          $block->content = $block->content = theme('activity_block', $activities);
        }
        break;

      case 'all':
        $block->title = "Everyone's Activity";
        $activities = activity_get_activity();
        if (count($activities)) {
          $block->content = theme('activity_block', $activities);
        }
        break;
      
      default:
        $block->content = "No content available";
    }

  } else {
    $block->content = "No content available";
  }

  return $block;
}

/**
 * 'Edit' callback for the 'activity' content type. 
 */
function activity_panels_configure($id, $parents, $conf = array()) {
  // Apply defaults
  if (empty($conf)) {
    $conf = array('title' => '', 'whose' => '');
  }
  
  $options = array('user'=>'User','buddies'=>'Buddies','all'=>'All');
  $form['whose'] = array(
    '#type' => 'radios',
    '#title' => t('Whos activity'),
    '#options' => $options,
    '#default_value' => $conf['whose'],
    '#prefix' => '<div class="clear-block no-float">',
    '#suffix' => '</div>',
  );
  
  return $form;
}

/**
 * 'Title' callback for the 'activity' content type. 
 */
function activity_panels_configure_title($conf, $context) {
  return t('"@s" activity', array('@s' => $conf['whose']));
}

