<?php

/**
 * Return "user info" content type.
 */
function userinfo_content_type() {
  return array(
    'description' => array(
      'title' => t('User Info'),
      'icon' => 'icon_user.png',
      'path' => panels_get_path('content_types/user'),
      'description' => t('User information gathered from helper modules.'),
      'required context' => new panels_required_context(t('User'), 'user'),
      'category' => array(t('User context'), -9),
    ),
  );
}

/**
 * Output function for the 'user info' content type.
 */
function userinfo_content($conf, $panel_args, $context) {
  $account = isset($context->data) ? drupal_clone($context->data) : NULL;
  $block->module = 'userinfo';
  $block->title = "User Info";
  
  if ($account) {
    $vars = userinfo_uservars($vars, $account); 
    $block->content = theme('userinfo', $account, $vars); 
  } else {
    $block->content = "No content available";
  }

  return $block;
}

/**
 * Creates variables related to the given user, mostly from functions provided by other modules.
 * The "$vars" parameter allows this to be called from _phptemplate_variables as well
 */
function userinfo_uservars($vars, $account) {
  $themedir = advanced_profile_get_theme_directory();
  
  // The passed in $account refers to the user who's info is in the pane.
  $accountid = $account->uid;
  
  // Get a reference to the currently logged in user. 
  global $user;
  
  // Avatar
  $vars['picture'] = theme('user_picture',$account);

  // Join date / since
  $vars['joined_raw'] = format_date($account->created, 'custom', 'Y-m-d');
  $vars['joined'] = '<div class="account-joined"><strong>' . t('Joined: ') . '</strong>' . $vars['joined_raw'] . '</div>';

  $vars['member_since_raw'] = format_interval(time() - $account->created);
  $vars['member_since'] = '<div class="account-member-since">' . t('Member since: ') . $vars['member_since_raw'] . '</div>';
  
  // Online status
  if (round((time()-$account->access)/60) < 15) {
    $vars['online_class'] = 'user-online';
    $vars['online_icon'] = theme_image(path_to_theme() . '/' . $themedir . '/images/status_online.png', 'User is online', 'User is online',NULL, TRUE);
    $vars['online_text'] = t('Online');
    $vars['online_status'] = '<div class="user-online">' . $vars['online_icon'] . ' ' . $vars['online_text'] . '</div>';
  } else {
    $vars['online_class'] = 'user-offline';
    $vars['online_icon'] = theme_image(path_to_theme() . '/' . $themedir . '/images/status_offline.png', 'User is offline', 'User is offline',NULL, TRUE);
    $vars['online_text'] = t('Offline');
    $vars['online_status'] = '<div class="user-offline">' . $vars['online_icon'] . ' ' . $vars['online_text'] . '</div>';
  }

  // Points
  if (module_exists('userpoints')) {
    $vars['points_raw'] = userpoints_get_current_points($accountid);
    $vars['points'] = '<div class="user-points">' . t('Points: ') . $vars['points_raw'] . '</div>';
  }

  // Posts
  if (module_exists('user_postcounts')) {
    $vars['posts_raw'] = user_postcounts_get_postcount($accountid);
    $vars['posts'] = '<div class="user-posts">' . t('Posts: ') . $vars['posts_raw'] . '</div>';
  }
 
  // Title
  if (module_exists('user_titles')) {
    $vars['user_title_raw'] = user_titles_get_user_title($accountid);
    $vars['user_title'] = '<div class="user-title">' . $vars['user_title_raw'] . '</div>';
  }

  // Badges
  if (module_exists('user_badges')) {
    $vars['user_badges_raw'] = user_badges_for_uid($accountid);
    $vars['user_badges'] = '<div class="user-badges">' . $vars['user_badges_raw'] . '</div>';
  }

  // Contact user
  if (($account->contact) && ($account->uid != $user->uid) && ($user->uid != 0)) {
    $vars['contact_class'] = "contact";
    $vars['contact_icon'] = theme_image(path_to_theme() . '/' . $themedir . "/images/email.png", 'Email', 'Email', NULL, TRUE);
    $vars['contact_text'] = t('Email'); 
    $vars['contact_link'] = 'user/'. $accountid . '/contact';
    $vars['contact'] = '<div class="contact">' . 
                          l($vars['contact_icon'] . ' '  . $vars['contact_text'], $vars['contact_link'],NULL,NULL,NULL,NULL,TRUE) . 
                          '</div>';
  } 
           
  // Send private message
  if (module_exists('privatemsg') && ($account->uid != $user->uid) && user_access('access private messages') && 
  (isset($account->privatemsg_allow) ? $account->privatemsg_allow : 1)) { 
    $vars['privatemsg_icon'] = theme_image(path_to_theme() . '/' . $themedir . "/images/user_comment.png", 'Private Message', 'Private Message', NULL, TRUE);theme_image(path_to_theme() . '/' . $themedir . "/images/email.png", 'Email', 'Email', NULL, TRUE);
    $vars['privatemsg_text'] = t('Send PM'); 
    $vars['privatemsg_link'] = 'privatemsg/new/'. $accountid;
    $vars['privatemsg'] = '<div class="privatemsg">' . 
                          l($vars['privatemsg_icon'] . ' '  . $vars['privatemsg_text'], $vars['privatemsg_link'],NULL,NULL,NULL,NULL,TRUE) . 
                          '</div>';
  } 

  // Add / remove from buddylist
  if (module_exists('buddylist')) {
  
    if (user_access('maintain buddy list') && @in_array($accountid, array_keys(buddylist_get_buddies($user->uid)))) {
      // Remove buddy
      $vars['buddylist_class'] = "buddy-remove";
      $vars['buddylist_icon'] = theme_image(path_to_theme() . '/' . $themedir . "/images/group_delete.png", 'Remove Buddy', 'Remove Buddy', NULL, TRUE);
      $vars['buddylist_text'] = t('Remove buddy'); 
      $vars['buddylist_link'] = 'buddy/delete/'. $accountid;
    } else {
      // Add buddy
      if ($accountid != $user->uid && user_access('maintain buddy list')) {
        $vars['buddylist_class'] = "buddy-add";
        $vars['buddylist_icon'] = theme_image(path_to_theme() . '/' . $themedir . "/images/group_add.png", 'Add to buddy list', 'Add to buddy list', NULL, TRUE);
        $vars['buddylist_text'] = t('Add buddy'); 
        $vars['buddylist_link'] = 'buddy/add/'. $accountid;
      }
    }
    
    $vars['buddylist'] = '<div class="' . $vars['buddylist_class'] . '">' . 
                         l($vars['buddylist_icon'] . ' '  . $vars['buddylist_text'], $vars['buddylist_link'],NULL,NULL,NULL,NULL,TRUE) . 
                         '</div>';
  }
  
  return $vars;
}


/**
 * Theme function for the user pane. Takes in the variables created in userinfo_uservars
 */
function theme_userinfo($account, $vars) {
  $themedir = advanced_profile_get_theme_directory();
  
  if (file_exists($themedir . '/panel-user-info.tpl.php')) {
    return _phptemplate_callback($themedir . '/panel-user-info',array_merge(array('account'=>$account), $vars));
  } else {
    //No .tpl file so output some basic formatting.
    $output = '<div class="user-info">';
    $output .= $vars['user_title']; 
    $output .= $vars['posts']; 
    $output .= $vars['joined']; 
    $output .= $vars['points'];
    $output .= $vars['user_badges']; 
    $output .= $vars['online_status']; 
    $output .= $vars['contact']; 
    $output .= $vars['privatemsg']; 
    $output .= $vars['buddylist']; 
    $output .= '</div>';

    return $output;
  }
}
